.. Asya documentation master file, created by
   sphinx-quickstart on Sun Dec 10 16:37:42 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Asya's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   cli
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
